@@ -8,23 +8,8 @@ package Fake::Our;
 # Copyright (c) 2014, 2015, 2017 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$Fake::Our::VERSION = 0.08;
+$Fake::Our::VERSION = 0.09;
 
-# > I sent PAUSE Distribution file: Fake-Encode-0.03.tar.gz, then I got a
-# > message "Status: Decreasing version number"
-# > module : Fake::Encode
-# > version: undef
-# >
-# > Why I got message "version: undefh?
-#
-# If I look at your module, I see:
-#
-#     $VERSION =
-#     $VERSION = 0.03;
-#
-# Get rid of that first line! :-)
-
-BEGIN { pop @INC if $INC[-1] eq '.' } # CVE-2016-1238: Important unsafe module load path flaw
 use 5.00503;
 # use strict; # since import() use $^H
 local $^W = 1;
